  /****************************************************************************
  * Title                 :   BIG 7 SEG R click
  * Filename              :   Big7SEGFT90x.c
  * Author                :   SP
  * Origin Date           :   17/11/2016
  *****************************************************************************/
  /**
  * @note Test configuration:
  * MCU:             FT900
  * Dev.Board:       EasyFT90x Pro v7
  * Oscillator:      100 MHz external
  * Ext. Modules:    BIG 7-SEG R Click
  * SW:              FT90x v2.0.0
  * NOTES:
    - Place BIG 7-SEG R click board on mikroBUS slot 1
    - PWM: GP56  _PWM_CHANNEL_0
    - RESET: GP01
    - LATCH: GP28
  *
  /******************************************************************************
  * Includes
  *******************************************************************************/
   #include "7_Seg.h"
  /******************************************************************************
  * Preprocessor Constants
  *******************************************************************************/

  /******************************************************************************
  * Configuration Constants
  *******************************************************************************/

  /******************************************************************************
  * Macros
  *******************************************************************************/

  /******************************************************************************
  * Typedefs
  *******************************************************************************/

  /* Module Variable Definitions
  *******************************************************************************/
  sbit HC595_RES at GPIO_PIN1_bit;
  sbit HC595_LAT at GPIO_PIN28_bit;
  sbit HC595_PWM at GPIO_PIN56_bit;
  /******************************************************************************

  /******************************************************************************
  * Function Definitions
  *******************************************************************************/
  extern char dig_array[MAX_CHARACTERS];

  // Variables
  unsigned short counter;
  unsigned int luminosity;
  unsigned int pwm_period;
  int8_t valid;

  char demo_array[20] =
  { 'M', 'I', 'K', 'R', 'O',
    'E', 'L', 'E', 'K', 'T', 'R', 'O', 'N', 'I', 'K', 'A',
    '2', '0', '1', '6'
  };

  void main()
    {
     // MCU Init
     GPIO_Pin_Digital_Output(_GPIO_PIN_NUM_1);   // Set GPIO_PIN1_bit as digital input
     GPIO_Pin_Digital_Output(_GPIO_PIN_NUM_28);  // Set GPIO_PIN28_bit as digital output

     // Initialize SPI
     SPIM1_Init_Advanced(_SPI_MASTER_CLK_RATIO_64,
                          _SPI_CFG_PHASE_CAPTURE_FALLING |
                          _SPI_CFG_POLARITY_IDLE_LOW |
                          _SPI_CFG_SS_AUTO_DISABLE |
                          _SPI_CFG_FIFO_DISABLE,
                          _SPI_SS_LINE_NONE );

      // Sets the SPIM1 module active
      SPIM_Set_Active(SPIM1_Write_Bytes, 
                      SPIM1_Write, 
                      SPIM1_Read_Bytes, 
                      SPIM1_Read, 
                      SPIM1_Enable_SS, 
                      SPIM1_Disable_SS); 
      
      // Initialize PWM2 module at 5kHz
      pwm_period = PWM_Init(5000);                   
      PWM_ConfigChannel(18000,                   // Set current duty for PWM on channel 0
                        _PWM_INIT_STATE_0, 
                        _PWM_CHANNEL_0); 
      PWM_EnableOutput();

       //74HC595 Init
       HC595_LAT = 0;
       HC595_RES = 0;
       HC595_reset();

       // Init counter and segment luminosity
       counter = 0;
       luminosity = 0;

       // Endless loop
       while (1)
       {
           valid = seg_7_display(demo_array[counter]);
           
           // Set current duty for PWM2 on channel 0
           PWM_ConfigChannel(18000 - luminosity, 
                             _PWM_INIT_STATE_0, 
                             _PWM_CHANNEL_0); 
           delay_ms (750 );
           luminosity += 100;
           counter++;

           if (counter == 20)       
             counter = 0;          
           if (luminosity == 4000)
             luminosity = 0;     
        }
  }